﻿# -----------------------------------------------------------------
# Check for Current Sessions
# Created by: Christopher Clai - www.syntaxbearror.io
# -----------------------------------------------------------------
# Version 1.0 (August 5th, 2019)
# -----------------------------------------------------------------
#
# Example of running the script:
# .\scan_sessions.ps1 -mode[workstation|server|all] (define which type of system you want to scan)
#
#
# ##### CHANGELOG ########
# Version 1.0
# 
#
#

# Retrieve parameters if run on a single use.

    param (
	    [Parameter(Mandatory=$True,ValueFromPipeline=$True,ValueFromPipelineByPropertyName=$True,HelpMessage='Do you want to run this against workstations, servers, or all?')]
	    $mode
    )


Import-Module ActiveDirectory

# Record what we find.
Start-Transcript -Path "scan_logons.txt" -Append

# Determine what we are seeking today
if($mode -eq "all") {

    $servers = Get-ADComputer -Filter "OperatingSystem -like 'Windows'" -Properties * | Select Name | select -ExpandProperty Name

}
elseif ($mode -eq "server") {

    $servers = Get-ADComputer -Filter "OperatingSystem -like 'Windows *Server*'" -Properties * | Select Name | select -ExpandProperty Name
}
elseif ($mode -eq "workstation") {

    $servers = Get-ADComputer -Filter "OperatingSystem -like 'Windows *7*'" -Properties * | Select Name | select -ExpandProperty Name
    $servers += Get-ADComputer -Filter "OperatingSystem -like 'Windows *10*'" -Properties * | Select Name | select -ExpandProperty Name

}
else {

    Write-Host "Scan mode is not defined. We cannot continue."
    exit
}

ForEach ($server in $servers) {

 If(Test-Connection -BufferSize 32 -Count 1 -ComputerName $server -Quiet) {
    Write-Host "`r`n $server is Online. Checking logged on users...`r`n"

    quser /server $server | Out-Default


 }
 else
 {
    write-host "$server is not online... Checking next system...`r`n" 
 }                           

}

stop-transcript 